<template>
  <div class="mod-config">
    <basic-container>
      <ttable
        :table="table"
        @handleSelectionChange="handleSelectionChange"
        @currentChange="handleCurrentChange"
        @rowClick="rowClick"
        :uploadInfo="uploadInfo"
        :prelang="prelang"
        :options="options"
        :ajaxFun="ajaxFun"
        ref="reportTable"
      >
        <template #toolbar></template>
      </ttable>

      <!-- 弹窗, 新增 / 修改 -->
      <table-form
        v-if="addOrUpdateVisible"
        ref="addOrUpdate"
        @refreshDataList="getData"
      ></table-form>
    </basic-container>
  </div>
</template>

<script>
import { getTestReportProcessingPage, delObj } from '@/api/quality/testreport'
import TableForm from './partprocessing-form'
import { mapGetters } from 'vuex'
import ttable from '@/views/common/ztt-table.vue'
import { getReportObj } from '../../../api/quality/testreport'

export default {
  data() {
    return {
      currentRow: null,
      reportItems: [],
      ajaxFun: getTestReportProcessingPage,
      addOrUpdateVisible: false,
      isShowQuery: false,
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'operation',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: false, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'testTime', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          // 零件编号
          {
            minWidth: '120',
            prop: 'partNo',
            label: '零件编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 检测描述
          {
            minWidth: '140',
            prop: 'templateDesc',
            label: '检测描述',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 零件名称
          {
            minWidth: '120',
            prop: 'partDesc',
            label: '零件名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 零件规格
          {
            minWidth: '120',
            prop: 'partSpecs',
            label: '零件规格',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 检测结论
          {
            minWidth: '120',
            prop: 'testResult',
            label: '检测结论',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 检测次数
          {
            minWidth: '140',
            prop: 'testCount',
            label: '检测次数',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 检测时间
          {
            minWidth: '120',
            width: '200',
            prop: 'testTime',
            label: '检测时间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'datetimerange'
          },
          // 检测人
          {
            minWidth: '140',
            prop: 'testUser',
            label: '检测人',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 备注
          {
            minWidth: '120',
            prop: 'remark',
            label: '备注',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 不合格数量
          {
            minWidth: '140',
            prop: 'number',
            label: '不合格数量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 处理日期
          {
            minWidth: '120',
            width: '200',
            prop: 'updateTime',
            label: '检测时间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'datetimerange'
          },
          // 处理人
          {
            minWidth: '140',
            prop: 'updateUser',
            label: '检测人',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 备注
          {
            minWidth: '120',
            prop: 'remarks',
            label: '备注',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 处理类型
          {
            minWidth: '120',
            prop: 'type',
            label: '处理类型',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          }
        ],
        toolbar: [
          {
            text: '不合格处理',
            type: 'primary',
            fun: this.addOrUpdateHandle
          }
        ],
        operatorConfig: {
          fixed: 'right',
          label: '操作',
          width: 200,
          minWidth: 100
        },
        isRefresh: {
          isRefresh: true,
          fun: this.RefreshData
        }
      }
    }
  },
  components: {
    TableForm,
    ttable
  },
  computed: {
    ...mapGetters(['permissions'])
  },
  methods: {
    // 获取数据列表
    getData() {
      this.$refs.reportTable.getDataList()
    },
    // 新增 / 修改
    addOrUpdateHandle(row) {
      if (this.currentRow == null) {
        this.$message.error('请选择一条不合格记录')
      } else {
        this.addOrUpdateVisible = true
        this.$nextTick(() => {
          this.$refs.addOrUpdate.init(this.currentRow.id)
        })
      }
    },
    rowClick(row) {
      getReportObj(row.id).then((response) => {
        this.reportItems = response.data.data.reportItems
      })
    },
    // 删除
    deleteHandle(row) {
      this.$confirm('是否确认删除此检测汇报', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        closeOnClickModal: false,
        type: 'warning'
      })
        .then(function() {
          return delObj(row.id)
        })
        .then((data) => {
          this.$message.success('删除成功')
          this.getData()
        })
    },
    handleSelectionChange(val) {
      this.multipleSelection = val
    },
    handleCurrentChange(val) {
      this.currentRow = val
    },
    getTestRuleTypeList() {
      return this.TestRuleTypeList
    }
  }
}
</script>
